@@ -28,10 +28,11 @@
 // e.g., CELLGRID=n, which sets CELLBORDER=0 and has the border drawing
 // handled correctly by the table.
 
+#include "config.h"
+
 #include <assert.h>
 #include <common/render.h>
 #include <common/htmltable.h>
-#include <cgraph/gv_math.h>
 #include <common/pointset.h>
 #include <cdt/cdt.h>
 #include <float.h>
@@ -46,6 +47,7 @@
 #include <util/alloc.h>
 #include <util/bitarray.h>
 #include <util/exit.h>
+#include <util/gv_math.h>
 #include <util/prisize_t.h>
 #include <util/strcasecmp.h>
 #include <util/streq.h>
@@ -380,7 +382,6 @@ initAnchor(GVJ_t * job, htmlenv_t * env, htmldata_t * data, boxf b,
   htmlmap_data_t * save)
 {
     obj_state_t *obj = job->obj;
-    int changed;
     char *id;
     static int anchorId;
     agxbuf xb = {0};
@@ -399,7 +400,7 @@ initAnchor(GVJ_t * job, htmlenv_t * env, htmldata_t * data, boxf b,
 	agxbprint(&xb, "%s_%d", env->objid, anchorId++);
 	id = agxbuse(&xb);
     }
-    changed =
+    const bool changed =
 	initMapData(job, NULL, data->href, data->title, data->target, id,
 		    obj->u.g);
     agxbfree(&xb);
@@ -452,7 +453,6 @@ emit_html_rules(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env, char *color, html
     pointf rule_pt;
     double rule_length;
     double base;
-    boxf pts = cp->data.box;
     pointf pos = env->pos;
 
     if (!color)
@@ -460,7 +460,7 @@ emit_html_rules(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env, char *color, html
     gvrender_set_fillcolor(job, color);
     gvrender_set_pencolor(job, color);
 
-    pts = cp->data.box;
+    boxf pts = cp->data.box;
     pts.LL.x += pos.x;
     pts.UR.x += pos.x;
     pts.LL.y += pos.y;
@@ -518,7 +518,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 {
     boxf pts = tbl->data.box;
     pointf pos = env->pos;
-    htmlcell_t **cells = tbl->u.n.cells;
+    htmlcell_t **cells = tbl->cells;
     htmlcell_t *cp;
     static textfont_t savef;
     htmlmap_data_t saved;
@@ -566,7 +566,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 	 * At present, we set the penwidth to 1 for rules until we provide the calculations to take
 	 * into account wider rules.
 	 */
-	cells = tbl->u.n.cells;
+	cells = tbl->cells;
 	gvrender_set_penwidth(job, 1.0);
 	while ((cp = *cells++)) {
 	    if (cp->hruled || cp->vruled)
@@ -802,24 +802,20 @@ void free_html_data(htmldata_t * dp)
 
 void free_html_text(htmltxt_t * t)
 {
-    htextspan_t *tl;
-    textspan_t *ti;
-
     if (!t)
 	return;
 
-    tl = t->spans;
+    htextspan_t *const tl = t->spans;
     for (size_t i = 0; i < t->nspans; i++) {
-	ti = tl->items;
-	for (size_t j = 0; j < tl->nitems; j++) {
-	    free(ti->str);
-	    if (ti->layout && ti->free_layout)
-		ti->free_layout(ti->layout);
-	    ti++;
+	textspan_t *const ti = tl[i].items;
+	for (size_t j = 0; j < tl[i].nitems; j++) {
+	    free(ti[j].str);
+	    if (ti[j].layout && ti[j].free_layout)
+		ti[j].free_layout(ti[j].layout);
 	}
-	tl++;
+	free(ti);
     }
-    free(t->spans);
+    free(tl);
     free(t);
 }
 
@@ -837,17 +833,18 @@ static void free_html_cell(htmlcell_t * cp)
 }
 
 /* If tbl->row_count is `SIZE_MAX`, table is in initial state from
- * HTML parse, with data stored in u.p. Once run through processTbl,
- * data is stored in u.n and tbl->row_count is < `SIZE_MAX`.
+ * HTML parse, with data stored in `tbl->prev` and `tbl->rows`. Once run through
+ * processTbl, data is stored in `tbl->parent` and `tbl->cells`, and
+ * tbl->row_count is < `SIZE_MAX`.
  */
 static void free_html_tbl(htmltbl_t * tbl)
 {
     htmlcell_t **cells;
 
     if (tbl->row_count == SIZE_MAX) { // raw, parsed table
-	rows_free(&tbl->u.p.rows);
+	LIST_FREE(&tbl->rows);
     } else {
-	cells = tbl->u.n.cells;
+	cells = tbl->cells;
 
 	free(tbl->heights);
 	free(tbl->widths);
@@ -855,7 +852,7 @@ static void free_html_tbl(htmltbl_t * tbl)
 	    free_html_cell(*cells);
 	    cells++;
 	}
-	free(tbl->u.n.cells);
+	free(tbl->cells);
     }
     free_html_data(&tbl->data);
     free(tbl);
@@ -902,7 +899,7 @@ static htmldata_t *portToTbl(htmltbl_t * tp, char *id)
 	rv = &tp->data;
     else {
 	rv = NULL;
-	cells = tp->u.n.cells;
+	cells = tp->cells;
 	while ((cp = *cells++)) {
 	    if ((rv = portToCell(cp, id)))
 		break;
@@ -1185,7 +1182,7 @@ static uint16_t findCol(PointSet *ps, int row, int col, htmlcell_t *cellp) {
 static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
 {
     htmlcell_t **cells;
-    rows_t rows = tbl->u.p.rows;
+    rows_t rows = tbl->rows;
     int rv = 0;
     size_t n_rows = 0;
     size_t n_cols = 0;
@@ -1193,20 +1190,20 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
     bitarray_t is = bitarray_new((size_t)UINT16_MAX + 1);
 
     size_t cnt = 0;
-    for (uint16_t r = 0; r < rows_size(&rows); ++r) {
-	row_t *rp = rows_get(&rows, r);
-	cnt += cells_size(&rp->rp);
+    for (uint16_t r = 0; r < LIST_SIZE(&rows); ++r) {
+	row_t *rp = LIST_GET(&rows, r);
+	cnt += LIST_SIZE(&rp->rp);
 	if (rp->ruled) {
 	    bitarray_set(&is, r + 1, true);
 	}
     }
 
-    cells = tbl->u.n.cells = gv_calloc(cnt + 1, sizeof(htmlcell_t *));
-    for (uint16_t r = 0; r < rows_size(&rows); ++r) {
-	row_t *rp = rows_get(&rows, r);
+    cells = tbl->cells = gv_calloc(cnt + 1, sizeof(htmlcell_t *));
+    for (uint16_t r = 0; r < LIST_SIZE(&rows); ++r) {
+	row_t *rp = LIST_GET(&rows, r);
 	uint16_t c = 0;
-	for (size_t i = 0; i < cells_size(&rp->rp); ++i) {
-	    htmlcell_t *cellp = cells_get(&rp->rp, i);
+	for (size_t i = 0; i < LIST_SIZE(&rp->rp); ++i) {
+	    htmlcell_t *cellp = LIST_GET(&rp->rp, i);
 	    *cells++ = cellp;
 	    rv |= size_html_cell(g, cellp, tbl, env);
 	    c = findCol(ps, r, c, cellp);
@@ -1221,7 +1218,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
     }
     tbl->row_count = n_rows;
     tbl->column_count = n_cols;
-    rows_free(&rows);
+    LIST_FREE(&rows);
     bitarray_reset(&is);
     freePS(ps);
     return rv;
@@ -1260,7 +1257,7 @@ static void set_cell_widths(htmltbl_t *table) {
   // largest minimum cell width …”. Note that this loop and the following one
   // could be fused, but this would make the implementation harder to relate
   // back to the specification.
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     const htmlcell_t cell = **i;
     if (cell.colspan > 1) {
       continue;
@@ -1273,7 +1270,7 @@ static void set_cell_widths(htmltbl_t *table) {
   // widths of the columns it spans so that together, they are at least as wide
   // as the cell. … If possible, widen all spanned columns by approximately the
   // same amount.”
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     const htmlcell_t cell = **i;
     if (cell.colspan == 1) {
       continue;
@@ -1299,7 +1296,7 @@ static void set_cell_widths(htmltbl_t *table) {
   }
 
   // take the minimum width for each column and apply it to its contained cells
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     htmlcell_t *cell = *i;
 
     // what is the current width of this cell’s column(s)’ span?
@@ -1326,7 +1323,7 @@ static void set_cell_heights(htmltbl_t *table) {
   assert(table->heights == NULL && "table heights computed twice");
   table->heights = gv_calloc(table->row_count + 1, sizeof(double));
 
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     const htmlcell_t cell = **i;
     if (cell.rowspan > 1) {
       continue;
@@ -1336,7 +1333,7 @@ static void set_cell_heights(htmltbl_t *table) {
         fmax(table->heights[cell.row], cell.data.box.UR.y);
   }
 
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     const htmlcell_t cell = **i;
     if (cell.rowspan == 1) {
       continue;
@@ -1359,7 +1356,7 @@ static void set_cell_heights(htmltbl_t *table) {
     }
   }
 
-  for (htmlcell_t **i = table->u.n.cells; *i != NULL; ++i) {
+  for (htmlcell_t **i = table->cells; *i != NULL; ++i) {
     htmlcell_t *cell = *i;
 
     double min_height = 0;
@@ -1545,13 +1542,12 @@ static void pos_html_cell(htmlcell_t *cp, boxf pos, unsigned char sides) {
  */
 static void pos_html_tbl(htmltbl_t *tbl, boxf pos, unsigned char sides) {
     int plus;
-    htmlcell_t **cells = tbl->u.n.cells;
+    htmlcell_t **cells = tbl->cells;
     htmlcell_t *cp;
     boxf cbox;
 
-    if (tbl->u.n.parent && tbl->u.n.parent->data.pencolor
-	&& !tbl->data.pencolor)
-	tbl->data.pencolor = gv_strdup(tbl->u.n.parent->data.pencolor);
+    if (tbl->parent && tbl->parent->data.pencolor && !tbl->data.pencolor)
+	tbl->data.pencolor = gv_strdup(tbl->parent->data.pencolor);
 
     double oldsz = tbl->data.box.UR.x;
     double delx = fmax(pos.UR.x - pos.LL.x - oldsz, 0);
@@ -1649,7 +1645,7 @@ size_html_tbl(graph_t * g, htmltbl_t * tbl, htmlcell_t * parent,
 
     if (tbl->font)
 	pushFontInfo(env, tbl->font, &savef);
-    tbl->u.n.parent = parent;
+    tbl->parent = parent;
     rv = processTbl(g, tbl, env);
 
     /* Set up border and spacing */
@@ -1797,7 +1793,7 @@ void printData(htmldata_t * dp)
 
 void printTbl(htmltbl_t * tbl, int ind)
 {
-    htmlcell_t **cells = tbl->u.n.cells;
+    htmlcell_t **cells = tbl->cells;
     indent(ind);
     fprintf(stderr, "tbl (%p) %" PRISIZE_T " %" PRISIZE_T " ", tbl, tbl->column_count, tbl->row_count);
     printData(&tbl->data);
